@@ -4,6 +4,7 @@ from collections import defaultdict
 from django import template
 
 from mezzanine.pages.models import Page
+from mezzanine.settings import PAGES_MENU_SHOW_ALL
 
 
 register = template.Library()
@@ -18,11 +19,14 @@ def _page_menu(context, parent_page, page_qs):
     if "menu_pages" not in context:
         pages = defaultdict(list)
         for page in page_qs.order_by("ordering"):
+            slug = context["request"].path.strip("/")
+            setattr(page, "selected", slug.startswith(page.slug))
             pages[page.parent_id].append(page)
         context["menu_pages"] = pages
     if parent_page is not None:
         parent_page = parent_page.id
     context["page_branch"] = context["menu_pages"].get(parent_page, [])
+    context["PAGES_MENU_SHOW_ALL"] = PAGES_MENU_SHOW_ALL
     return context
 
 @register.inclusion_tag("pages/includes/page_menu.html", takes_context=True)
@@ -40,3 +44,4 @@ def page_menu_admin(context, parent_page=None):
     """
     return _page_menu(context, parent_page, 
         Page.objects.published(for_user=context["request"].user))
+
