@@ -21,6 +21,9 @@ BLOG_POST_PER_PAGE = 5
 # Maximum number of paging links to show on a blog listing page.
 BLOG_POST_MAX_PAGING_LINKS = 10
 
+# Slug of the page object for the blog.
+BLOG_SLUG = "blog"
+
 # Shortname when using the Disqus comments system (http://disqus.com).
 COMMENTS_DISQUS_SHORTNAME = None
 
@@ -51,6 +54,19 @@ CONTENT_STATUS_CHOICES = (
     (CONTENT_STATUS_PUBLISHED, _("Published")),
 )
 
+# ID for using Google Analytics (http://www.google.com/analytics/) referred to 
+# as "Web Property ID"
+GOOGLE_ANALYTICS_ID = None
+
 # Number of different sizes given to tags when shown as a cloud.
 TAG_CLOUD_SIZES = 4
 
+# Store these package names here as they may change in the future since at the 
+# moment we are using custom forks of them.
+PACKAGE_NAME_FILEBROWSER = "filebrowser_safe"
+PACKAGE_NAME_GRAPPELLI = "grappelli_safe"
+
+# If True, the pages menu will show all levels of navigation by default, 
+# otherwise child pages are only shown when viewing the parent page.
+PAGES_MENU_SHOW_ALL = True
+
